package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$"`0`````````````#`!0````!```9Q````#0``0&(```````T`"``
M"``H`!P`&P````8````T````-````#0```$````!``````4````$`````P``
M`30```$T```!-`````T````-````!`````$````!``````````````````"5
M1```E40````%``$```````$``/R8``'\F``!_)@```/4```3[`````8``0``
M`````@``_>0``?WD``']Y````1````$0````!@````0````$```!1````40`
M``%$````1````$0````$````!&1TY5$`````````````````````````````
M``8````09'3E4@``_)@``?R8``'\F````V@```-H````!`````$O;&EB+VQD
M+G-O+C$`````````!````!`````!1TY5```````````#`````@`````````$
M````%`````-'3E4`-8GX\#L7I@[Y(T`X5K*:=,0RPNH````1````3@````@`
M```(!!`0`(`$0"4````H@`"&H````8`)!"@+11*@.`@(!(H`````````3@``
M`%(```!6````5P```%T```!>````7P```&$```!B`````````&0```!E````
M9@```&<``````````!_?Q6X.[]/J+4?>SGR:?VNVF\4N#N3_(`[QC;A\U&35
M'%AQV0'&1^+`XTNL?)+CNBP_Y<)@;*'Z;XL!L]9#"6MFS*]G[-5%0M-P!XF>
MXA0-GN/-VNW;8C,+ESH-FYRI?PH"I^%)^^"C````````````````````````
M`````!<8``````,```L```*P```````````2```````#7@``````````$@``
M`````?X``````````!(````````1```````````@```````#=P``````````
M$0```````]T``````````!(```````+]```````````1```````#3P``````
M````$@```````24``````````!(```````++```````````2````````R```
M````````$@```````9<``````````!(```````*W```````````2````````
MF```````````$@```````2```````````!(```````.!```````````2````
M```#!```````````$@```````14``````````!$```````)X```````````2
M```````!>P``````````$@```````/<``````````!$```````,+````````
M```2```````!20``````````$@```````-8``````````!(```````,R````
M```````B```````!Q0``````````$@```````D<``````````!(```````'V
M```````````2```````"E```````````$@```````;(``````````!(`````
M``*%```````````2```````!O@``````````$@```````5<``````````!(`
M``````,4```````````2````````+0``````````(````````ED`````````
M`!(```````'0```````````1```````#(0``````````$@```````'@`````
M`````!(```````*B```````````2```````#90``````````$@```````>\`
M`````````!(```````"G```````````2```````#00``````````$@``````
M`+,``````````!(```````%P```````````2```````"J0``````````$@``
M`````G\``````````!(```````)F```````````2```````!-@``````````
M$@```````A<``````````!(```````*-```````````2````````:@``````
M````$@```````2H``````````!(```````+2```````````2```````!IP``
M````````$@```````KT``````````!(```````$$```````````2```````#
M5P``````````$@```````IL``````````!(```````-X```````````A````
M```!B0``````````$@```````(<``````````!(````````\```````````@
M````````Z```````````$@```````6<``````````!(```````,H````````
M```2````````4```````````(````````EX``````````!(```````-Y````
M```````1```````"\P``````````$@```````@,``````````!(```````+@
M```````````2```````"*```````````$@```````F\``````````!(`````
M``+K```````````2```````#Y@``3%````#L$@``#````[0``%/@`````!(`
M``T```0+```]@```"N02```,```#<@``%V````)D$@``#````[H``#0@````
M#!(```P```1J```T,````E02```,```$9```%Q@`````$@``"P``!)<``$AP
M```#X!(```P```.9``(`;``````0```9```#\@``-I````!4$@``#````C@`
M`%0,````!!$```X```.E``(0A``````0```9```$8@``,G````!0$@``#```
M!'<``#O@```!G!(```P```2)```ZP````,`2```,```$&``"`!``````$```
M%P```_\``#;P```!V!(```P```.2``(`;``````0```8```$2P`"`&@````$
M$0``&````ZH``$YP````!!(```P```0[``!-L````,`2```,```$'@``&<0`
M```T$@``#```!!H``@`0`````"```!<```/+```[@````%@2```,```$)0``
M,S````#L$@``#```!%4``#C0```!Y!(```P`;&EB<&5R;"YS;RXU+C(R`%])
M5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?2G9?
M4F5G:7-T97)#;&%S<V5S`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E
M<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT
M`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P
M=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P
M97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?
M<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`
M<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P
M97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE
M;6]R>5]W<F%P`&QI8G!T:')E860N<V\N,`!O<&5N-C0`;'-E96LV-`!R96%D
M`'!T:')E861?9V5T<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!L
M:6)C+G-O+C8`7TE/7W-T9&EN7W5S960`7U]R96=I<W1E<E]A=&9O<FL`97AI
M=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`'5N;&EN:P!M:V1I<@!R96%L
M;&]C`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US970`<W1R<W1R
M`')M9&ER`%]?9G!R:6YT9E]C:&L`;65M8W!Y`%]?<W1R;F-P>5]C:&L`7U]L
M>'-T870V-`!O<&5N9&ER`%]?>'-T870V-`!S=&1E<G(`9V5T=6ED`')E861L
M:6YK`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?8WAA7V9I;F%L
M:7IE`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB
M8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?7W-T86-K7V-H:U]F86EL`%]E9&%T
M80!?7V)S<U]S=&%R=`!?96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N
M=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P
M`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A
M7W-T87)T`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`
M;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P
M87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]0
M05)?0D]/5`!'3$E"0U\R+C(`1TQ)0D-?,BXP`$=,24)#7S(N,RXT`$=,24)#
M7S(N,RXR`$=,24)#7S(N,2XS`$=,24)#7S(N-``````````"``(``P````(`
M`@`"``(``@`"```````"```````$``(````"```````"```````%````!@`'
M``(````"``(````(`````@````(````"``(`!P````0```````(``@`"````
M`P`"```````(````!`````(``@`"```````````````)`````@`"``D``P`)
M``,``@`"``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``(```'?````$````#`-:6D2````!P``!*T````0
M#6EI$`````,```2W```````!``8```(N````$``````-:6D2````"0``!*T`
M```0"6D9=`````@```3!````$`EI&7(````&```$S0```!`):1]S````!0``
M!-D````0#6EI%`````0```3E````$`UI:1`````"```$MP```````?R8````
M%@``&T```?R<````%@``&M```?RD````%@`"`&@``?RH````%@`"`&@``?RT
M````%@`"`&P``?R\````%@`"`!0``?S$````%@`!_*```?S,````%@`"`'``
M`?S0````%@``5$```?S8````%@``5$@``?S<````%@``5!```?SD````%@``
M5%@``?SH````%@``5T@``?SL````%@``2'```?SP````%@``5'0``?ST````
M%@``5(P``?SX````%@``5)```?S\````%@``5)P``?T`````%@``5*```?T$
M````%@``5*P``?T(````%@``5+P``?T,````%@``5,```?T0````%@``5,0`
M`?T4````%@``5,P``?T8````%@``5-@``?T<````%@``5.```?T@````%@``
M5.P``?TD````%@``5/0``?TH````%@``500``?TL````%@``51```?TP````
M%@``51P``?TT````%@``52@``?TX````%@``530``?T\````%@``54```?U`
M````%@``54P``?U$````%@``56```?U(````%@``570``?U,````%@``58``
M`?U0````%@``59```?U4````%@``5:0``?U8````%@``5;```?U<````%@`"
M`!@``?U@````%@``5;0``?UD````%@``5;P``?UH````%@``5<0``?UL````
M%@``5<P``?UP````%@``5=@``?UX````%@``5A0``?U\````%@``5AP``?V`
M````%@``5B0``?V$````%@``5C0``?V(````%@``5D0``?V,````%@``5YP`
M`?V0````%@``5E@``?V4````%@``5JP``?V8````%@``5K0``?V<````%@``
M5K@``?V@````%@``5L```?VD````%@``5L0``?VH````%@``5MP``?VL````
M%@``5N0``?VP````%@``5P@``?W$````%@``5C```?W(````%@``5TP``?W,
M````%@`"`&@``?W0````%@``5U```?W4````%@``,L```?W8````%@`"`!0`
M`?W<````%@`!_)P``?W@````%@`!_)@``@``````%@`!_O@``@`$````%@``
M%V```@`(````%@``3;```@`,````%@``3G```@`4````%@`"`!0``@`<````
M%@``5WP``@`@````%@``5XP``@`D````%@``5Y0``@`H````%@``5YP``@`L
M````%@``5Z0``@`P````%@``5[@``@`X````%@``5W0``@`\````%@``5)P`
M`@!$````%@``570``@!(````%@``57@``@!,````%@``5V@``@!0````%@``
M5*0``@!4````%@``5W```@!<````%@``5U0``@!@````%@``5UP``@!H````
M%@``5\0``?RL```%`0```````?RP``!%`0```````?RX```:`0```````?S`
M``!!`0```````?S(``!'`0```````?S4```3`0```````?S@```-`0``````
M`?UT```(`0```````?VT```S`0```````?VX``!``0```````?V\```6`0``
M`````?W````F`0```````?[T```D%````````?\$```"%0```````?\(```#
M%0```````?\,```$%0```````?\0```'%0```````?\4```)%0```````?\8
M```*%0```````?\<```+%0```````?\@```,%0```````?\D```.%0``````
M`?\H```/%0```````?\L```0%0```````?\P```1%0```````?\T```2%0``
M`````?\X```4%0```````?\\```5%0```````?]````7%0```````?]$```8
M%0```````?](```9%0```````?],```:%0```````?]0```;%0```````?]4
M```<%0```````?]8```=%0```````?]<```>%0```````?]@```?%0``````
M`?]D```@%0```````?]H```A%0```````?]L```B%0```````?]P```C%0``
M`````?]T```D%0```````?]X```E%0```````?]\```G%0```````?^````H
M%0```````?^$```I%0```````?^(```J%0```````?^,```K%0```````?^0
M```L%0```````?^4```M%0```````?^8```N%0```````?^<```O%0``````
M`?^@```P%0```````?^D```Q%0```````?^H```R%0```````?^L```T%0``
M`````?^P```U%0```````?^T```V%0```````?^X```W%0```````?^\```X
M%0```````?_````Y%0```````?_$```Z%0```````?_(```[%0```````?_,
M```\%0```````?_0```]%0```````?_4```_%0```````?_8``!"%0``````
M`?_<``!#%0```````?_@``!$%0```````?_D``!&%0```````?_H``!(%0``
M`````?_L``!)%0```````?_P``!*%0```````?_T``!+%0```````?_X``!,
M%0```````?_\``!-%0````"4(?_P?`@"II`!`!23P0`(0I\`!7_(`J8_W@`"
M.][GS(`>__PO@```0;X`"$@`.2V``0`4?`@#IH/!``@X(0`03H``(`````"4
M(?_`?`@"ID*?``63P0`XD`$`1'_(`J:3H0`TD&$`')"!`!B0H0`4DX$`,)/A
M`#PX@0`8.*$`%#AA`!P_W@`".]YE7($BC_B1(0`L.2```$@`./&`OH#L@'Z`
M\'RD*WA(`#6!@3Z`](NI```OG0``09X!9(/^@`R`?P``2``Z=8DC!/9\:AMX
M@'\``&$I``*9*@3V2``Z78$A`!P]0#__84K__SDI``6)`P3V?XE00&$*``&9
M0P3V09T!;%4C$#I(`#@!@3Z!!(%!`!B`H0`<@_Z`!($I``"!"@``?&L;>"^%
M``&0?Q`(D2,`"($^@0B1`P``@1Z!`)$C``PY(``$D0,`!)$_$`1`G0`T5*D0
M.CD#``PY*?_X52GPOCDI``%]*0.F8````&````!@````A2H`!)4H``1"`/_X
M5*D0.H">@0R`?Q`0.4```#DI``PXX```?69;>#BE``-]2TDN2``XX7Q]&WE!
M@@"8@'\0$#N!`"A(`#:]@'Z`8'^$XWA,QC&"2``0S2^#``!!G@"$@'\0$$@`
M-EU(`#AY?Z/K>(%!`"R!(H_X?4I*>3D@``!`@@"H@`$`1(.!`#"#H0`T@\$`
M.'P(`Z:#X0`\."$`0$Z``"!(`#:M@5Z`!"^#``"0:A`009X`>$@`-?F#_H`,
M@'\``$@`./V;HP=E2__^?(!_$!!(`#BM?'T;>$O__V"`?Q`,+X,``$&>`!Q(
M`#+52___<(">@/B`?H#\3,8Q@D@`-W&`?H`X?X3C>$S&,8)(`!`1+X,``)!_
M$`Q!GO]$2``RH4O__SQ(`#3).&```4@`-L%\*0MX5"$`-D*?``5]J`*F.```
M`)0A__!\"`.FD`$``#_-``(]#0`".][E*(6HYC!(`#;,``````````"4(?_P
M?`@"ID*?``63P0`(D`$`%'_(`J8_W@`".]YBF($^@`"`?H`$.2D``WTC2%`K
MB0`&0)T`&($^@`@OB0``09X`#'TI`Z9.@`0A@`$`%(/!``@X(0`0?`@#IDZ`
M`""4(?_P?`@"ID*?``63P0`(D`$`%'_(`J8_W@`".]YB.(!^@`2`GH``?(,@
M4'R$%G!\A`YP?(0!E4&"`!B!7H`,+XH``$&>``Q]20.F3H`$(8`!`!2#P0`(
M."$`$'P(`Z9.@``@8````&````!@````E"'_\'P(`J9"GP`%D\$`")`!`!1_
MR`*FD^$`##_>``([WF'(@_Z`$(D_```OB0``0)X`*($^@!0OB0``09X`$($^
M@!B`:0``2``TN4O__N4Y(``!F3\``(`!`!2#P0`(@^$`##@A`!!\"`.F3H``
M()0A__!\"`*F0I\`!9/!``B0`0`4?\@"IC_>``([WF%8@3Z`('TC2WB!(P``
M+XD``$">`""``0`4@\$`"#@A`!!\"`.F2__^W&````!@````@3Z`'"^)``!!
MGO_<?2D#IDZ`!"%+___0````````````````````````````````E"']0#E#
M`#!\"`*F.0```)`!`L23`0*@DR$"I)-!`JB380*LDX$"L).A`K23P0*XD^$"
MO#DA`!B`XH_XD.$"G#C@```XX``(?.D#ID@``!1@````8````&````!@````
MA,H`")$)``"1"0`(@.H`!)#)``0Y*0`0D.G__$(`_^0Y(`!`..$`>'TI`Z8X
M````A,<`"($'``2!)__8@4?_W(%G_ZB`A_^L?,9*>("G_YA]"E)X@2?_G'S(
M6GA]2B)X?0@J>'U)2GA5"@@\52D(/I`'`!A]*5-XD2<`'$(`_[2`PP`4@`,`
M!#U`6H*`HP`<@6,`#&%*>9F#@P``@(,`)%0'*#Z!(P`(@^$`''S=*GA5;/`^
M5X@H-%><\`*#80`T52GP`G_D^!1]C$MX?_]0%($A`"1\Z$-X?Z=8.'T(^!1\
M_RIX?,=B>'T(^!2#X0`L?.<`.'TE2!1]*5`4?.<R>%0=\#Y]*3@4?[SC>%4'
M*#Y]*3@4?1W@.'V'0'A_YO@4?.?K>'^_4!1\Y^@451_P/H.A`#Q5*"@^?YI(
M>'SG0!1].?@X?1M0%'];RWA]"&`452GP/GT;0!14^R@^?0C8%'SY2#B#80!$
M?_HX>'^]4!1_6LMX?YW@%'^:X!14_?`^50<H/GT9Z#A\_#@4?3I`>(.!`$Q_
M>U`4?UK+>'][^!15'_`^?WK8%%3H*#Y]&T`4?/GX.(-A`%1_NCAX?YQ0%']:
MRWA]/$@45.?P/E4<*#Y].D@4?1DX.'TIX!1_^D!X@X$`7'][4!1_6LMX?WOH
M%%4=\#Y_>M@452@H/GT;0!1].>@X@V$`9'SZ2'A_G%`4?UK+>'_\^!1_^O@4
M53SP/E4)*#Y]&>`X?3](%'^Z0'A_^U`4?UK+>(-A`&Q\_S@451_P/GSZ.!15
M*"@^?0=`%'TY^#B`X0!T?YI(>'][4!1_6LMX?WOH%']ZV!15/?`^50DH/GT9
MZ#A].T@4?_I`>(-A`'Q\YU`4?UK+>'^'X!15!_`^?YK@%%4H*#Y]'$`4?3DX
M.'^Z2'A_FU`4@V$`A']:RWA_G/@4?YK@%%4_\#Y5"2@^?1GX.'T\2!1\^D!X
M@X$`C'][4!1_6LMX?WOH%%4=\#Y_>M@452@H/GT;0!1].>@X@V$`E'_Z2'A_
MG%`4?UK+>'^<.!1_FN`452?P/E4)*#Y]&3@X?3Q(%'^Z0'B#@0"<?WM0%']:
MRWA_>_@451_P/G]ZV!15*"@^?1M`%'TY^#B#80"D?/I(>'^<4!1_6LMX?YSH
M%'^:X!15/?`^50DH/G_Z0'A]/$@4?0SH.(.!`*Q_>U`4?TQC>'S[.!15&O`^
M?.PX%%4H*#Y\YT`4?[M(>'TLT#A]'%`4@X$`M']L8WA]"/@453OP/E3_*#Y]
M#$`4?.G8.'V(^!1_7SAX@0$`O'U<4!1__TMX?2KH%#U`;MEA2NNA5/WP/G__
M2!15G"@^@2$`Q'^?X!1_9^IX?0A0%'SG8GA]"-`459_P/GT(.!17AR@^?.@X
M%'^L^GB!`0#,?2E0%'V,XGA]*=@45YKP/GTI8!14["@^?8E@%'_\TGB!(0#4
M?0A0%%3[\#Y_J.@4?X@Z>(#A`-Q_O4`458@H/G^]0!1_2-IX?2E0%%6<\#Y_
MZ?@4?0EB>($!`.1__T@45ZDH/G__2!1_;.)X@2$`['SG4!1]C.IX?.?0%%>]
M\#Y\YV`45^PH/GV'8!1_A^IX?0A0%'SG^GA]"-@45_KP/GT(.!15AR@^?.@X
M%'^_TGB!`0#T?2E0%'__8GA]*>`459OP/GTI^!14["@^?8E@%']?VGB!(0#\
M?0A0%%3\\#Y_J.@4?^@Z>'^]0!15B"@^?1U`%']GXGA_Z5`4?.=B>($A`01_
M_]`459WP/H-!`5Q__S@450PH/GV?8!1_G^IX?.E0%($A`0Q\Y]@4?_M">'SG
MV!15'_`^58@H/G^[^GA\YT`4?0E0%($A`11_>V)X?0C@%'T(V!15G/`^5.PH
M/G_[XGA]B&`4?2E0%($!`1Q_J>@4?VDZ>'^]2!14^_`^@.$!)%6)*#Y_O4@4
M?XG:>'T(4!1]*6)X?^CX%%6(\#Y__T@45ZPH/H$A`2Q]GV`4?W]">'SG4!1_
M_^IX?.?@%%>\\#Y\Y_@459\H/G_G^!1]'>)X@.$!-'TI4!1]*=@4?[MB>'TI
MV!15G?`^5^PH/G^;ZGA]B6`4?.=0%($A`3Q]!T`4?V?Z>'T(.!17__`^58<H
M/G^[^GA\Z#@4?0E0%($A`41_>V)X?0C@%'T(V!15G/`^5/LH/GT(V!1_^^)X
M?8E0%'][.GB!(0%,?8SH%%3]\#Y]C-@450<H/GV,.!1_F^IX?.E0%'][0GB!
M(0%4?.?X%%4?\#Y\Y]@458@H/GSG0!1_N?IX?4E0%%6;\#Y]"N`4?RQB>#U`
MCQM4_"@^84J\W'_IVWA]"&`4?_G8.(&!`6Q]".`4?2DX.'^*T!14Y_`^@T$!
M9'^\Z!1]*<MX?2GH%']\.WA5'2@^?WDX.'^IZ!1_G$`X?TK0%%4)\#Y_G,MX
M?_KX%(-!`71\Z$MX?_SX%%>\*#Y]".@X?__@%'S\2#A]BF`45[WP/G]LV!1]
M".-X@8$!?'^(V!1]*.MX5_LH/GTYZ#A_?-@4?0CX.'^*T!17__`^@T$!A'S\
M.!1]",MX?[S[>'T(.!179R@^?[GX.'T(.!1_G-@X?8I@%%=G\#Y_G,MX?2Q(
M%(&!`:Q5&R@^?3Q(%'_\.WA]*=@4@V$!C'_Y.#A_2M`4?YQ`.'^ZZ!15"/`^
M?YS+>%4Z*#Y_G.@4?/U#>'^<T!2#00&4?/E`.']JV!1_O4@X?_OX%%4I\#Y_
MO<MX5YLH/G^]^!1]'TMX?[W8%(-A`9Q]&4@X?TK0%'__X#A\^C@45YSP/G__
MRWA7NB@^?/\X%'T_XWA\Y]`4@T$!I'TYX#A__^@X?VK8%%>]\#Y_>T`4?__+
M>'__V!1_B.MX5/LH/G^9Z#A_?]@4?0@X.'_JT!14Y_`^@T$!M'__2!1]",MX
M?0CX%'^I.WA7?R@^?2G8.'_H^!1_J#@X?8I@%%=[\#Y_C.`4?2E#>(&!`;Q]
M">`4?.G;>%?\*#Y]*?@X?XC@%'SHV#A_2M`45__P/G^ZZ!1]*4-X@T$!Q'T)
MZ!1_:?MX5YTH/GTIX#A_J.@4?VCX.'V*8!17G/`^?.PX%'TI0WA]"3@4?^GC
M>%>G*#Y_^>`X?.@X%'TIZ#A]"M`45[WP/H-!`<Q]"-@4?2G+>'^;ZWA]*4`4
M5.@H/G^9Z#A]"4`4?VDX.']JT!14Y_`^@T$!U'_[^!1]*<MX51LH/GTI^!1_
MOSMX?2G8%(-A`=Q_N3@X?TK0%'__0#A_FN`450CP/G__RWA5.B@^?__@%'S\
M0WA__]`4@T$!Y'SY0#A_:M@4?YQ(.'^[Z!15*?`^?YS+>%?[*#Y_O.@4?1Q+
M>'^]V!2#80'L?1E(.']*T!1_G/@X?/HX%%?_\#Y_G,MX?YPX%%>L*#Y])_MX
M?9Q@%'TY^#A_BM@4?.?H.%>Z\#Z#H0'T?1Q`%'SGRWA\YT`459LH/G_HTWA_
M9]@4@.$"!'T(8#A__-`X?4KH%'T<XWB#H0'\?4I(%#T@RF)A*<'658SP/GU<
M4!17?"@^?XK@%'](8GA]2>@45WWP/G_J^!1]"MIX@0$"#'__4!17BB@^?_]0
M%'V*ZGA\Z3@4?4KB>'SGT!17FO`^?.=0%%?J*#Y\YU`4?[O2>(%!`A1]"4`4
M?WOZ>'T(8!17__`^?0C8%%3[*#Y_:-@4?USZ>($!`AQ]25`4?YPZ>'U*Z!14
M[/`^?4K@%%=\*#Y_BN`4?^=B>(%!`B1]"4`45YGP/G^HT!1\Z-IX@.$"+%=Z
M\#Y_O4`45X@H/G];RGA_O4`4?8C2>'U)4!1_>^IX?^KX%'T*XGB!`0(T?_]0
M%%>J*#Y__U`4?.DX%(%!`CQ\YV`45[WP/GSGV!17^R@^?V?8%'\\ZGB`X0)$
M?0E`%'^<^GA]"-`45_CP/GT(X!17?"@^?XC@%'^ZPGA]25`4?UK:>'U*R!17
M;/`^?4K0%%>:*#Y_2M`4?QMB>(%!`DQ\Z3@4?WOB>'^GZ!17A_`^?[W8%%=;
M*#Y_?=@4?9PZ>'_I4!1_G-)X@4$"5'__P!177?`^?__@%%=\*#Y_G^`4?/KJ
M>'T)4!1_6MIX@4$"7'T(8!17?_`^?0C0%%>:*#Y_2-`4?[OZ>($!`F1]25`4
M?WOB>'SJ.!17C/`^@4$"='SGV!176R@^?V?8%'_\8GB`X0)L?0E`%'^<TGA_
MJ.@45UKP/H$!`GQ_O>`45WPH/G^=X!1\Z3@4?9W2>'_G^!1_O=IX5WOP/G__
MZ!17G2@^?[_H%']'VGA]25`4?.?B>'U*8!17G/`^?4HX%%>G*#Y]2C@4?W_B
M>(#A`H1]"4`4?__J>'T(T!17O?`^?0CX%%5?*#Y]"/@4?YKJ>(/A`HQ\Z3@4
M?.?8%'];4GB#00*454KP/GSGV!15&R@^?.?8%'^[4GA_Z?@4?__@%']\0GA_
M_^`450CP/E3\*#Y__^`4?5Q">'TIT!1]*>@4?YTZ>'TIZ!17_2@^?2GH%%3G
M\#X[H```?2D`%'UK^!1\YS`4?0@H%'U*(!20XP`4DZ,``)$C``23HP`(D6,`
M#).C`!"3HP`8D0,`').C`""10P`D@4$"G(#BC_A]2CIY..```$""`#2``0+$
M@P$"H(,A`J2#00*H?`@#IH-A`JR#@0*P@Z$"M(/!`KB#X0*\."$"P$Z``"!(
M`"398````)0A_]`L`P``?`@"ID*?``63P0`HD`$`-'_(`J:3(0`4DT$`&)-A
M`!R3@0`@DZ$`))/A`"P_W@`".]Y3"$&"`)2!/H``@TD``"^:``!!G@"$B2,`
M`"^)``!!G@#H*XD`/3N@``!!G@`@?'T;>(T]``$NB0``*XD`/4&6``A`GO_P
M?Z/H4(/Z```OGP``09X`1'R9(WA\>QMX?US3>&````!_X_MX?Z7K>']DVWA(
M`"?5+X,``$">`!!]/^BN+XD`/4&>`$"'_``$+Y\``$">_]2``0`T@R$`%#A@
M``"#00`8@V$`''P(`Z:#@0`@@Z$`)(/!`"B#X0`L."$`,$Z``"!_FN!0.'T`
M`7^<%G!\?QH4DYD``(`!`#2#(0`4@T$`&(-A`!Q\"`.F@X$`((.A`"2#P0`H
M@^$`+#@A`#!.@``@.Z```$O__T!@````8````)0A_]!\"`*F0I\`!9.A`"23
MP0`H?\@"II/A`"R0`0`T?'T;>#OA`!@_W@`".]Y1O($BC_B1(0`<.2```'_D
M^WA_H^MX3,8Q@DO__FDO@P``09X`:&````!@````8````($^@`"!00`8@0D`
M`%5*$#I]*%(4A.D`!"^'``!\Z%$N09[_O&````!@````8````(5)``0OB@``
MD4G__$">__1_Y/MX?Z/K>$S&,8)+__X%+X,``$">_ZR!00`<@2*/^'U*2GDY
M(```0((`((`!`#2#H0`D@\$`*(/A`"PX(0`P?`@#IDZ``"!(`"*98````)0A
M_[!\"`*F0I\`!9`!`%2380`\DX$`0).A`$23P0!(D^$`3'_(`J:2X0`LDP$`
M,),A`#2300`X?'\;>#_>``([WE#,B20``&DI`#TA*0``@2*/^)$A`!PY(```
M?X0!E'^#XWA(`"1=.($`&'Q[&WA_X_MX3,8Q@DO__4E\?1MY08(!<$@`)#U_
MFQA`0)T!-(-!`!B#/H``5UH0.HD_```OB0``09X"`"N)`#U!G@'X?^/[>$@`
M`!1@````8````"N)`#U!G@`0C2,``2^)``!`GO_P?'\84#M[``*#N0``?'L:
M%$@`(VTO@P``?'W1+D&>`<B)/P``@4$`&($9``!52A`Z+XD``'U(4"Z9*@``
M09X`."N)`#U!G@`P?^/[>$@``!A@````8````&`````KB0`]09X`%(TC``&=
M*@`!+XD``$">_^PY(``].'S__YDJ``!@````8````&````"-(P`!G2H``2^)
M``!`GO_T.&```(%!`!R!(H_X?4I*>3D@``!`@@$\@`$`5(+A`"R#`0`P@R$`
M-'P(`Z:#00`X@V$`/(.!`$"#H0!$@\$`2(/A`$PX(0!03H``(&`````X?/__
M.5W__V````!@````C2,``9TJ``$OB0``0)[_]$O__Y!@````8````&````"#
M/H``@OD``($W```OB0``09X`K'[HNW@Y0```2```"'^JZWB%*``$.ZH``2^)
M``!`GO_P.4H``U5$$#J!7H`$@2H``"^)``!!G@`X?N.[>$@`(@$O@P``D'D`
M`$&>`&Q7NA`Z.3T``3E```!5*1`Z?4-)+I.A`!A+__XT8````#D@``%\@R-X
MD2H``$@`(=5\>!MY08(`-%>Z$#I^Y+MX?T73>$@`(&V3&0``?P/#>$O__[0X
M8```2__^,#B```@[H```2___>#A@__]+__ZX2``?T6````!@````8````)0A
M_V!\"`*F0I\`!9.!`)"3P0"8?\@"II`!`*2300"(DV$`C).A`)23X0"<?'P;
M>3_>``([WDW\@2*/^)$A`'PY(```08(`$(D\```OB0``0)X`0(%!`'R!(H_X
M?4I*>3D@``!`@@%$@`$`I(-!`(B#80",@X$`D'P(`Z:#H0"4@\$`F(/A`)PX
M(0"@3H``($@`(T%\?1MY08+_O#M!`!!_H^MX2``BO2P#``!!@@"DB2,`$R^)
M`"Y!G@"X.^,`$W^#XWA(`"$M?'L;>'_C^WA(`"$A?'L:%#AC``)(`""E@-Z`
M"'_H^WA_A^-X.*#__SB```%\>QMX3,8Q@D@`(35_1=-X?V3;>#A@``-(`")U
M+X/__W]CVWA!G@`4@2$`(%4I!"8KB4``09X`>$@`'Y5_8]MX2``?#7^CZWA(
M`"(E+`,``$""_VQ@````8````'^CZWA(`")M?X/C>$@`'Q5+__[T8````&``
M``!@````B2,`%"^)``!!GO\H*XD`+D">_SR)(P`5+XD``$&>_Q1+__\L8```
M`&````!@````2__^84O__XQ(`!X98````)0A_^!\"`*F0I\`!9/!`!B0`0`D
M?\@"II.A`!23X0`<?'T;>#_>``([WDQ,@_Z`#(!_``!(`"&M?Z3K>#BC`4@X
M8``#2``AK2^#``!!G@`D@`$`)(.A`!0X8```@\$`&(/A`!PX(0`@?`@#IDZ`
M`""`?P``2``A;8$C`5A5*00F*XE``$&>`""`?P``2``A58$C`5A5*00F;2K_
M_R^*H`!`GO^P?Z/K>#B```)(`""U@`$`)(.A`!2#P0`8@^$`'#@A`"!\"`.F
M?&,`-%1CV7Y.@``@8````&````!@````E"'OP#B@#_]\"`*F0I\`!9/!$#B3
M81`L?\@"II.!$#"3H1`TD`$01)/A$#Q\?!MX.Z$`''R;(WA_I.MX/]X``CO>
M2VB`?H`0@2*/^)$A$!PY(```2``=_2P#``!`@0"D.^/__SE!$"!]*OH4B2GO
M_"^)``!!G@!\?'\;>'_E^W@X@``O?Z/K>$@`'XDO@P``09X`<($^@`R`:0``
M2``@97_F^WA_I>MX?X3C>$@`(`6!(1`<@4*/^'TI4GDY0```0((`7(`!$$2#
M81`L@X$0,(.A$#1\"`.F@\$0.(/A$#PX(1!`3H``(&````!@````+Y\``$">
M_XA@````8````($^@`R`:0``2``?^7]EVWA_A.-X2``=34O__YA(`!P5E"'_
MX'P(`J9"GP`%D\$`&)`!`"1_R`*F/]X``CO>2DR!/H`,@&D``$@`'[F`WH`4
M@+Z`&(">@!Q(`!YI@`$`)(/!`!@X(0`@?`@#IDZ``""4(?_@?`@"ID*?``63
MP0`8D`$`)'_(`J:3X0`</]X``CO>2?R#_H`,@'\``$@`'V5+__^!@'\``$@`
M'UF`_H`@@+Z`)#D```"`GH`H?.8[>$@`'K&``0`D@\$`&(/A`!PX(0`@?`@#
MIDZ``"!@````E"'?T'P(`J9"GP`%D\$@*)`!(#1_R`*FD^$@+).!(""3H2`D
M.^$`%#_>``([WDF,@2*/^)$A(!PY(```2``<I8$>@"R`WH`P.*`0`3B```%\
M9QMX?^/[>$S&,8)(`!UE+X,``$&<`'P[@1`8.*`0`'^$XWA_X_MX2``;^7Q]
M&WE!@`!@.'T``4@`'(E\?QMY08(`4'^EZWA_A.-X2``;13D@``!_X_MX?3_I
MKH%!(!R!(H_X?4I*>3D@``!`@@`L@`$@-(.!(""#H2`D@\$@*'P(`Z:#X2`L
M."$@,$Z``"`X8```2___R$@`&FE@````E"'_\#@A`!!+__\(8````)0A[[!\
M"`*F0I\`!7V``":3P1!(D`$05'_(`J:301`XDX$00)/A$$R1@1`HDN$0+),!
M$#"3(1`TDV$0/).A$$0_W@`"?'P;>#O>2(Q\GR-X@'Z`.#B!`!B!(H_XD2$0
M'#D@``!,QC&"2__U&3B``"]\>AMX?X/C>$@`&^DO@P``09X`:(!^@#Q_A.-X
M3,8Q@DO_]S%_@^-X@4$0'($BC_A]2DIY.2```$""`:B``1!4@8$0*(+A$"R#
M`1`P?`@#IH,A$#2#01`X?8"!((-A$#R#@1!`@Z$01(/!$$B#X1!,."$04$Z`
M`"!_@^-X+AH``$@`&Y&#/H!`?'@;>'\DRWA_X_MX2``<K7Q]&WE!@O]X.N``
M`#L8``$[80`<8O>``#O@``!@````8````&````")/0``+XD``$">``B#OH`T
M09(`&'^DZWA_0]-X2``912^#``!!G@"\?Z/K>$@`&R5]71H4B2K__R^)`"]`
MG@`8G^K__SAC__^)*O__+XD`+T&>__!\>!H4+X,/_T&=_OB!'H!$@-Z`2'^G
MZWA_B>-X.*`0`#B```%_8]MX3,8Q@D@`&Q&#OH`,@'T``$@`'&5_9-MX.*,!
M2#A@``-(`!Q%+X,``$">`!R`?0``2``<18$C`5A5*00F?XFX`$&>`#1_),MX
M.&```$@`&[E\?1MX+YT``$">_RQ+__Y\8````'\DRWA(`!N=?'T;>$O__^0X
M@``!?V/;>$@`&WDO@P``0)[_P(!^@#Q_9-MX3,8Q@DO_]8%_8]MX2``:R4O_
M_DQ(`!@!8````&````!@````E"'_\(DC```OB0``09X`0#E#``%(```<8```
M`&````")*@``.4H``2^)``!!G@`@*XD`+T">_^R)*@``?4-3>#E*``$OB0``
M0)[_Z#@A`!!.@``@8````&````!@````E"'_X'P(`J9"GP`%D\$`&)/A`!Q_
MR`*F?'\;>9`!`"23H0`4/]X``CO>1<Q!@@!TB[\``"^=``!!G@!H2``9A3AC
M__]\OQH4?Y\H0$"<`.A]/QBN+XD`+T">`*A]/RA0?2D#ID@``!A@````8```
M`(DE```OB0`O0)X`B#BE__]"`/_P*YT`+T&>`!B`?H!$2``9P4@``"1@````
M8````#A@``)(`!BM+`,``$&"`#0Y("X`L2,``(`!`"2#H0`4@\$`&(/A`!PX
M(0`@?`@#IDZ``"!@````8````&````"``0`D@Z$`%#A@``"#P0`8@^$`'#@A
M`"!\"`.F3H``(#DE__]_GTA`?3\H4'TI`Z9!G0"P+Y___T"^`!1(``"DB24`
M`"^)`"]!G@`4.*7__T(`__!_GRA`0;[_3#DE__]_GTA`?3\H4'TI`Z9!G0"`
M+Y___T"^`!A(``!T8````(DE```OB0`O0)X`##BE__]"`/_P?+\H4#DE``(K
MB1``09W_8(!^@`1_Y/MX.,`0`#BE``$[HP`$?Z/K>$@`&06``0`D?Z/K>(/!
M`!B#H0`4@^$`'#@A`"!\"`.F3H``(#D@``%]*0.F2___9#D@``%]*0.F2___
MF&````!@````E"'_L#B@`")\"`*F0I\`!9/!`$B0`0!4?\@"II/A`$PX80`8
M.^$`%#_>``([WD/H@2*/^)$A`#PY(```@)Z`%#B$``Q(`!7]@'Z`3$S&,8)+
M__'A@'Z`4$S&,8)+__'5@'Z`5$S&,8)+__')@'Z`6$S&,8)+__&]@'Z`7$S&
M,8)+__&Q@'Z`8$S&,8)+__&E@'Z`.$S&,8)+__&9@'Z`9$S&,8)+__&-@'Z`
M:$S&,8)+__&!@'Z`;$S&,8)+__%U@'Z`/$S&,8)+__%I@'Z`<$S&,8)+__%=
M@'Z`=$S&,8)+__%1@'Z`>'_D^WA,QC&"2__O\7QD&WE!@@`0@'Z`:$S&,8)+
M__(=@'Z`?'_D^WA,QC&"2__OS7QD&WE!@@`0@'Z`@$S&,8)+__'Y@'Z`A'_D
M^WA,QC&"2__OJ7QD&WE!@@!0@'Z`.$S&,8)+__'5@)Z`D(!^@%Q,QC&"2__Q
MQ8%!`#R!(H_X?4I*>3D@``!`@@!P@`$`5(/!`$B#X0!,."$`4'P(`Z9.@``@
M8````(!^@(A_Y/MX3,8Q@DO_[T5\9!MY08(`'(!^@&1,QC&"2__Q<4O__YQ@
M````8````(">@(PXH``*.&$`*4@`%Y4O@P``0)[_?#B!`#-+___,2``3T6``
M``!@````8````)0A_]!\"`*F0I\`!9/!`"B3X0`L?\@"II`!`#0_W@`".]Y!
M_($BC_B1(0`<.2```(/^@)2`?P``+X/__T&>`#2!00`<@2*/^'U*2GDY(```
M0((`;(`!`#2#P0`H@^$`+#@A`#!\"`.F3H``(&````"`?H!D.($`&$S&,8)+
M_^YU+`,``$&"`"R)(P``.&```"^)``!!G@`0:2,`,#$C__]\:1D0D'\``$O_
M_YA@````.&```)!_``!+__^(2``3!90A_^!\"`*F0I\`!9/!`!B0`0`D?\@"
MIC_>``([WD$\2``3T4@`$STL`P``08(`)(!C``"``0`D@\$`&#@A`"!\"`.F
M3H``(&````!@````.&```$O__^!@````8````)0A_Z!\"`*F0I\`!9/!`%B3
MX0!<?\@"II`!`&23(0!$DT$`2)-A`$R3@0!0DZ$`5#_>``([WD#<@3Z`E(%"
MC_B100`\.4```(%)``2`B0`(@*D`#(#)`!"`Z0`4@0D`&'U?4WF!*0`<D4$`
M()"!`"20H0`HD,$`+)#A`#"1`0`TD2$`.$&"`'1\>QMX.Z$`(#M!`!Q(```D
M8````&````!(`!(Q+X,``$&>`)B'_0`$+Y\``$&>`$1_1--X?^/[>$S&,8)+
M_^T-?V3;>'Q\&WE!@@`0B5P``"^*``!`GO_$?^/[>$S&,8)+_^\IA_T`!"^?
M``!`GO_$@2$`/(%"C_A]*5)Y.4```$""`)"``0!D@R$`1(-!`$B#80!,?`@#
MIH.!`%"#H0!4@\$`6(/A`%PX(0!@3H``(&````!@````?V/;>$@`$XU\>1MX
M?X/C>$@`$X%\>1H4.&,``D@`$P6!'H!`@-Z`2'^)XWA_9]MX.*#__SB```%\
M>1MX3,8Q@D@`$Y%_),MX?^/[>$S&,8)+_^Z!2___6$@`$0E@````/`#__WPL
M"WA@`'ZP?"$!;GP(`J9"GP`%D\S_^'_(`J:3K/_TD`P`!#NA@1"3+/_DDTS_
MZ)-L_^R3C/_PD^S__'QZ&W@_W@`"DNS_W#O>/S`XG7\$@3Z`E(!^@#@^X0`!
MDDS_R))L_\R#Z0`L@`D`,(%I`#2`J0`X@,D`/(#I`$"!"0!$@4D`2(,I`""#
M:0`D@XD`*($I`$R2C/_0DJS_U)+,_]B3#/_@@P*/^),7@0P[````D_U_(),]
M?PB3?7\,DYU_$)`=?R21?7\HD+U_+)#=?S"0_7\TD1U_%)%=?QB1/7\<3,8Q
M@DO_ZTE\?QMY08(`$(D_```OB0``0)X$M$O__0$[_7\0.WU_!'Q\&WE!@@)@
M?X/C>$@`$AE48P@\.&,``4@`$9V(_```+X<``'Q[&WA!G@`T@SZ`G'Q_&WA_
MX_MX?R;+>#B@__\X@``!3,8Q@D@`$AV,_``!._\``B^'``!`GO_<?[_K>#L]
M?P2$?W\@+X,``$">`!1(``!4A'\`!"^#``!!G@!(?R3+>$S&,8)+_^J=?'P;
M>4&"_^2)/```+XD``$&>_]A+__%%+X,``$&>_\Q_@^-X2``2!7QY&WE`@@"`
M8````&````"#_7\(+Y\``$&>`<B)/P``.X```2^)``!`G@`\2``!M#E```!7
MB1`Z84J!$'U*"A1]*DH4/2G__X/I?P@OGP``09X!D(D_```[G``!+XD``$&>
M`8!_X_MX2__PR2^#``!!GO_`?^/[>$@`$8E\>1MY08+_L'\CRWA(`!#I?'\;
M>']CVWA(`!#=?'\:%#OC!`1_X_MX2``078+^@$2!/H"@?VK;>'\GRWB`WH"D
M.*#__SB```%\>!MX?NB[>$S&,8)(`!#A.(`!P'\#PWA(`!$5+X/__T&>`0R#
MGH`,@'P``$@`$B%_!,-X.*,!2#A@``-(`!(A+X,``$&>`2B!/H"L@-H``'\'
MPW@X@``!@+Z`R(!I``!,QC&"2``123A@```^X0`!@Q>!#(+BC_A_&+IY.N``
M`$""!]R!80``@`L`!()+_\B":__,@HO_T'P(`Z:"J__4@LO_V(+K_]R#"__@
M@RO_Y(-+_^B#:__L@XO_\(.K__2#R__X@^O__'UA6WA.@``@8````&````!@
M````2``087Q\&WE`@OVL8````(1_``0O@P``09X"2']DVWA,QC&"2__HK7QI
M&WE!@O_DB2D``"^)``!!GO_82___Q#L@``!+__Z@8````&````!(`!`A@0,`
M`"^(`!%!GO[L@3Z`K(#:``!_!\-X.(```8"^@*B`:0``3,8Q@D@`$%4X8```
M2___#&````!@````@'P``$@`$-V!(P%852D$)BN)0`!`GO[(@'P``$@`$,6#
M8P%@2``-W7^;&`!`GOZP@'P``$@`$*V!(P%852D%_BN)`<!`GOZ8?^/[>$@`
M#H4XG7\$?'L;>(!^@,1,QC&"2__GX2^#``!!G@%X@_H``$@`#V%\9!MX?^/[
M>$O_\D5\?!MY08(!7'^#XWA(``ZU+X,``WQ_&WA`G0`X.&/__(">@+!\?!H4
M2``,J2^#``!`G@`@+Y\`!$&>!4Q__/H4B3__^R^)`"]!G@4\8````$O_^($O
M@P``0)X`'#B```!_@^-X3,8Q@D@`#GE\=!MY0((`^(">@)"`?H!D.^```$S&
M,8)+_^E]2``-F8.^@""`WH"\?NB[>'\'PW@XH/__.(```7QI&WA_JNMX?V/;
M>$S&,8)(``Y-2```3&````!(``ZA@2,``"^)`!%`G@!,2``-49.A``@[_P`!
M@-Z`P'_J^WA^Z+MX?&D;>'\'PW@XH/__.(```7]CVWA,QC&"2``.`3B``<!_
M8]MX2``.-2^#__]!GO^L?P/#>$@`"_6`?H`X?V3;>$S&,8)+_^C5?V/;>$O_
M^+U_8]MX2__]1$O_^+%_X_MX2``."4O__32#GH"8.&``#4O_^UQ@````@YH`
M`$O__J0XH/__.,#_[CC@``([_7_\2``,F3B@``9_Y/MX?H.C>$@`"UF)/7_\
M+XD``$">`!")/7_]+XD`0T&>!%`XX```.*```#C```!^@Z-X2``,73T@9T4Y
M````82DC`9$=?SB1/7\\/2#OS6$IJXDY````D3U_1#T@F+IA*=S^D1U_0)$]
M?TP](!`R82E4=CD```"1/7]4/2##TF$IX?"1'7](.0```#E````Y8```D1U_
M4)$]?UPY````.2```)$=?UB177]@D7U_9)%=?VB1?7]LD3U_L#J]?_PZ8```
M.SU_<#K=?SA@````.*```'ZDJWA@I8``?H.C>$@`"H%\>AMY0($!0($]?V"!
M77]D?TC^<"N)``!721@X?2E0%$&=`NQ`G@`,?XI(0$&=`N"`W7]H@/U_;(!]
M?[!5!1@X5TH??GRJ4WA5"!]^+X,``'U*.!1]"#$4DGU_8)$]?V21'7]HD5U_
M;$&>`I0A(P!`?U+3>'^:2`!`G0`(?3)+>'Y%DWA^I*MX?'D:%$@`"C&!/7^P
M?3)*%"^)`$"1/7^P0)[_3'[#LWA_4M!0?E62%$O_UKU@````8````"^:`#]`
MG0!0?US3>'Y?DWA_Y/MX.*``0'\CRW@[G/_`2``)X7[#LW@[_P!`2__6A2^<
M`#]!G?_<.UK_P%=)T;X=2?_`.2D``54I,#)^4DH4?TK2%']%TW@XP`!(?D23
M>'\CRWA(``KMDUU_L#B@``!@I8``?J2K>'Z#HWA(``E%?'H;>4&!_LA^@Z-X
M.UU_<$@`#-&#_7]D.4#_@(.=?VQ7Z>Z^.&D``7U:2:XO@P`X09T!\""C`#@X
M@```?'H:%$@`"U%7A48^5X:$/E>'PCY7Z$8^5^J$/E?IPCXX?7\XF+U_J)C=
M?ZF8_7^JFYU_JYD=?ZR977^MF3U_KIO]?Z]+_]6Q@+U_/(#=?T2!'7],@5U_
M5($]?UQ4IT8^5*R$/E49A#Y5&L(^55Q&/E5?A#Y4LL(^5--&/E34A#Y4U<(^
M519&/E5`PCY5*T8^52.$/E4DPCZ;/7_%@SZ`G)M=?\:;G7_(F_U_R9C]?[R9
MG7^]FEU_OIB]?[^:?7_`FIU_P9J]?\*8W7_#FMU_Q)D=?\>8'7_*F5U_RYE]
M?\R8?7_-F)U_SID]?\\[_7_0.YU_O#M=?_A(```08````&````",_``!?^/[
M>'\FRW@XH/__.(```3O_``),QC&"2``*!7^:^$!`GO_<.6```(%>@""`WH"X
M.3U_T)E]?_A^Z+MX?P?#>#B@__\X@``!?V/;>$S&,8)(``G-?P/#>$@`!]6`
M?H`X?V3;>$S&,8)+_^2U?V/;>$O_])U_8]MX2__Y)#I=?_Q+__V\8````&``
M``"!77]L@-U_:##J``%\Q@&42__]'(/Z``0OGP``09[ZQ'_C^WA(``DM*X,`
M`T"=^K0X8__\@)Z`M'Q_&A1(``<E+X,``$">^IQ__/MX2__ZE""C`$`X@```
M.SU_.'QZ&A1(``EA?R/+>$O_T_DXH``X.(```']#TWA(``E)2__]^(D]?_XO
MB0!!0)[[K(D]?_\OB0!#0)[[H(DA`1`OB0!(0)[[E(DA`1$OB0!%0)[[B#C`
M_\8XX``".*#__WZ#HWA(``?A?^3[>#B@`"E^@Z-X2``&H8%>@""`WH"X?^G[
M>'[HNWA_!\-X.*#__SB```%_8]MX3,8Q@D@`")E+__JL2``&(6````!@````
M8````)0A_[!\"`*F0I\`!9/!`$B0`0!4?\@"II,!`#"3@0!`DL$`*)+A`"R3
M(0`TDT$`.)-A`#R3H0!$D^$`3#_>``([`0`8.]XT3(.>@`R`?```@2*/^)$A
M`!PY(```2``)A3D@``%_!,-XF2,`98!^@%Q,QC&"2__@S2P#``!!@@`0B2,`
M`"^)`#%!G@)H2__OU8!\``!(``E-@)Z`S#C```LXH``!2``'/8-^@`0L`P``
M08(`U($[$`2!0P`0+XD``8,J`!A`G0#`/N``(#N@```[X``!8O<$`$@``#!@
M````@(@`$'[#LWA(``5I@3L0!"^#``!`G@"$._\``3N]``%_B?@`0)T`=(!\
M``!(``C5.,```'^EZWA_),MX2``(97QZ&WE!@@(<@1H``(#[$`A7ZA`Z@2@`
M"'['4"Y^Z4@X*XD$`$&>_YR`?```2``(E8":```XP``".*```$@`!?5\9!MX
M?L.S>$@`!.F!.Q`$+X,``$&>_X0Y2?__?XKH`$&>`8"`?```2``(68">@-`X
MP``#.*```4@`!DE\?QMY08(`,(!\``!(``@Y@3\`$("^@-2`B0``2``%B8$_
M`!"!*0``@2D`"'4J`$!`@@'@@'P``$@`"`V`GH#8.,```SB@``%(``7]?'\;
M>4&"`#2`?H`\?P3#>$S&,8)+_]]%?'T;>8!\``!!@@&(2``'U8$_`!!_I>MX
M@(D``$@`!26`?```2``'O7Q_&WB`?```2``'L8">@-PXH``!2``&-8"^@.!\
M9!MX?^/[>$@`!/6`?```2``'C3D@``!_!,-XF2,`98!^@#A,QC&"2__>U2^#
M``!\?QMXD'L0#$&>`.0X@`'`?^/[>$@`!CDO@P`1?&8;>$&>`!`Y(P`!*XD`
M`4&=`2B!(0`<@4*/^'TI4GDY0```0((!$(`!`%2"P0`H@N$`+(,!`#!\"`.F
M@R$`-(-!`#B#80`\@X$`0(.A`$2#P0!(@^$`3#@A`%!.@``@B2,``2^)``!!
MGOV82__]D"^)``%`G?Z`.^```6````"`?```._\``4@`!LE_),MX2``#D8$[
M$`1_B?@`09W_Y$O__E1@````8````&````"!.Q`$.4G__W^*Z`!`GOXX2___
ML&````!@````8````(![$`A+__&M+X,``'Q_&WB0>Q`,0)[_#(!^@.1,QC&"
M2``%$6````!@````8````$@`!E&!6Q`(@3\`$("*``"`:0``2__E/4O__GB`
M?```2``&,8$_`!"`B0``2``%54O__A!(``)-@3L0"(!^@.A_Y?MX@(D``$S&
M,8)(``2UE"'_X'P(`J9"GP`%D\$`&).A`!1_R`*FD^$`')`!`"1\?1MX/]X`
M`CO>,&Q+_^IUB2,``'Q_&W@OB0``09X`0#E#``%(```<8````&````")*@``
M.4H``2^)``!!G@`@*XD`+T">_^R)*@``?5]3>#E*``$OB0``0)[_Z$O_[?4O
M@P``09X`+"^=``!!G@`DB3T``"^)``!!G@`8@)Z`H'_C^WA(``&]?Y\8`$&>
M`""``0`D@Z$`%(/!`!B#X0`<."$`('P(`Z9.@``@@`$`)(/!`!A_H^MX@^$`
M'(.A`!0X(0`@?`@#IDO_X8@`````E"'_\'P(`J9"GP`%D\$`")`!`!1_R`*F
M/]X``CO>,(R!/H``+XD``$&>`"B`R0``2``"@8`!`!2#P0`(."$`$'P(`Z9.
M@``@8````&`````XP```2``"78`!`!2#P0`(."$`$'P(`Z9.@``@`````)0A
M_]!\"`*F0I\`!9/!`"B3(0`4?\@"II-!`!B380`<DX$`()`!`#23H0`DD^$`
M+'QY&WA\FB-X?+LK>#_>``([WC`@2__))8$^@`2#GH``?XG@4'^<%G%!@@`\
M.ZG__#O@``!@````8````&````"%/0`$?V7;>']$TWA_(\MX?2D#ICO_``%.
M@`0A?Y_@0$">_^"``0`T@R$`%(-!`!B#80`<?`@#IH.!`""#H0`D@\$`*(/A
M`"PX(0`P3H``($Z``"````````````````"4(?_P?`@"ID*?``63P0`(D`$`
M%'_(`J8_W@`".]XO6$@``,$```````````````"!?H(\?6D#IDZ`!"!@````
M@7Z"0'UI`Z9.@`0@8````(%^@D1]:0.F3H`$(&````"!?H)(?6D#IDZ`!"!@
M````@7Z"3'UI`Z9.@`0@8````(%^@E!]:0.F3H`$(&````"!?H)4?6D#IDZ`
M!"!@````@7Z"6'UI`Z9.@`0@8````(%^@EQ]:0.F3H`$(&````"!?H)@?6D#
MIDZ`!"!@````@7Z"9'UI`Z9.@`0@8````(%^@4Q]:0.F3H`$(&````"!?H)L
M?6D#IDZ`!"!@````@7Z"<'UI`Z9.@`0@8````(%^@G1]:0.F3H`$(&````"!
M?H)X?6D#IDZ`!"!@````@7Z"?'UI`Z9.@`0@8````(%^@H!]:0.F3H`$(&``
M``"!?H*H?6D#IDZ`!"!@````@7Z"B'UI`Z9.@`0@8````(%^@7Q]:0.F3H`$
M(&````"!?H*0?6D#IDZ`!"!@````@7Z"E'UI`Z9.@`0@8````(%^@IA]:0.F
M3H`$(&````"!?H*<?6D#IDZ`!"!@````@7Z"H'UI`Z9.@`0@8````(%^@J1]
M:0.F3H`$(&````"!?H*H?6D#IDZ`!"!@````@7X`?'UI`Z9.@`0@8````(%^
M@K!]:0.F3H`$(&````"!?H*T?6D#IDZ`!"!@````@7Z"N'UI`Z9.@`0@8```
M`(%^@KQ]:0.F3H`$(&````"!?@"0?6D#IDZ`!"!@````@7Z"Q'UI`Z9.@`0@
M8````(%^@LA]:0.F3H`$(&````"!?H+,?6D#IDZ`!"!@````@7Z"T'UI`Z9.
M@`0@8````(%^@M1]:0.F3H`$(&````"!?H+8?6D#IDZ`!"!@````@7Z"W'UI
M`Z9.@`0@8````(%^@N!]:0.F3H`$(&````"!?H+D?6D#IDZ`!"!@````@7Z"
MZ'UI`Z9.@`0@8````(%^@NQ]:0.F3H`$(&````"!?H+P?6D#IDZ`!"!@````
M@7Z"]'UI`Z9.@`0@8````(%^@OA]:0.F3H`$(&````"!?H+\?6D#IDZ`!"!@
M````@7Z#`'UI`Z9.@`0@8````(%^@P1]:0.F3H`$(&````"!?H,(?6D#IDZ`
M!"!@````@7Z##'UI`Z9.@`0@8````(%^@Q!]:0.F3H`$(&````"!?H,4?6D#
MIDZ`!"!@````@7Z#&'UI`Z9.@`0@8````(%^@QQ]:0.F3H`$(&````"!?H,@
M?6D#IDZ`!"!@````@7Z#)'UI`Z9.@`0@8````(%^@RA]:0.F3H`$(&````"!
M?H,L?6D#IDZ`!"!@````@7Z#,'UI`Z9.@`0@8````(%^@S1]:0.F3H`$(&``
M``!(``$`2```_$@``/A(``#T2```\$@``.Q(``#H2```Y$@``.!(``#<2```
MV$@``-1(``#02```S$@``,A(``#$2```P$@``+Q(``"X2```M$@``+!(``"L
M2```J$@``*1(``"@2```G$@``)A(``"42```D$@``(Q(``"(2```A$@``(!(
M``!\2```>$@``'1(``!P2```;$@``&A(``!D2```8$@``%Q(``!82```5$@`
M`%!(``!,2```2$@``$1(``!`2```/$@``#A(```T2```,$@``"Q(```H2```
M)&````!@````8````&````!@````8````&````!@````/6L``'P(`J9"GP`%
M.6L!#'V(`J9\"`.F?6Q84#V,``*`#*M0@8RK5'P)`Z9\"UH4?6!:%$Z`!"!@
M````8````)0A__!\"`*FD`$`%)/!``A"GP`%?\@"IH`!`!1\"`.F@\$`"#@A
M`!!.@``@``(``7!E<FQX<VDN8P```%]?14Y67U!!4E]#3$5!3E]?("`@("`@
M("`@("`@("`@`````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D
M97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5`````!E
M>&4`+W!R;V,O)6DO)7,`+@```%!!4E]414U0`````%!!4E]04D]'3D%-10``
M```Z````+P```"5S)7,E<P``4$523#5,24(`````4$523$Q)0@!015),-4]0
M5`````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?
M0TQ%04X```!005)?1$5"54<```!005)?0T%#2$4```!005)?05)'0P````!0
M05)?05)'5E\P``!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?5$U0
M1$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?
M0TQ%04X`````4$%27T-,14%./0``,0```%-94U1%30``)3`R>`````!P87(M
M`````"5S)7,E<R5S`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I
M<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``'!A<FP`````+G!A<@``
M```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U
M+25U)7,`````)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F
M92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI
M"@``05)'5@`````8````<&5R;``````P````4$%2.CI086-K97(Z.E9%4E-)
M3TX`````,2XP,S4```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R
M>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M+0``55-%4@````!5
M4T523D%-10````!414U01$E2`%1-4``O=&UP`````$Q$7TQ)0E)!4EE?4$%4
M2`!,24)0051(`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)0E)!4EE?4$%42```
M`%-(3$E"7U!!5$@``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@
M)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE
M;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE
M+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U
M:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ
M9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN
M("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H
M("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D
M<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R
M)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T
M;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P
M9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT
M("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D
M;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=
M.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE
M"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T
M;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO
M9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO
M=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@
M8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI)
M;G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ
M4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PII9B`H97AI<W1S
M("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["D!!
M4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%2
M7T%21T-]("T@,2D["B0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*
M9F]R("AK97ES("5%3E8I('L*9&5L971E("1%3E9[)%]](&EF("]>4$%27T%2
M1U9?+SL*?0I]"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#
M;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G
M.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\
M3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H
M)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R
M;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D
M871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P
M96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D[
M"FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T
M(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D
M<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@
M,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*
M;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR
M96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@
M/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I
M.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O
M9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE
M<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@
M+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O
M9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L
M(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L
M:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U
M;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN
M86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<
M9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT
M*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(
M+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD[
M"FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX
M?&%L*20O:2D@>PIM>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D
M97AT+"`D8W)C*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@
M)&]U="`D8G5F.PIC;&]S92`D;W5T.PIC:&UO9"`P-S4U+"`D9FEL96YA;64[
M"GT*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N
M86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L
M;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N
M9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2`B
M)$5.5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["F]U=',H(E-(3$E".B`D
M9FEL96YA;65<;B(I.PIO<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R
M(&1I92`D(3L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S
M92`D;W5T.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD
M4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^
M("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR
M96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D
M<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R
M("$D;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES
M='LD;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E
M<75I<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME
M>2`]("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF
M(&1E9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@
M(B]L;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%
M04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D[
M"G!R:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D[
M"G)E='5R;B`D9F@["GT*96QS92!["FUY("@D;W5T+"`D;F%M92D@/2!?=&5M
M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PII9B`H)&]U="D@>PIB
M:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["F-L
M;W-E("1O=70["GT*;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A
M.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P
M:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4[
M"G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI
M<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M
M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI
M('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U
M;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*
M9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S
M<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L
M;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%
M?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE
M;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S
M=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S
M:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II
M("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R
M"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@
M)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5]
M(#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I
M;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@
M/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q
M(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@
M97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@
M>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@
M>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@
M)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG
M.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H
M)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA8
M6#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@
M>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A
M<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F
M:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P
M87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD
M(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE
M=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD
M;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@
M/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R
M(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I
M<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T
M(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=2
M3TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@
M)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@
M7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E
M<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD
M("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^
M87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")0
M05)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I
M8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@
M;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O
M(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL
M92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI
M*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY
M("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A0
M86-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L
M"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G
M/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM
M;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_
M.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7
M<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R
M:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E
M0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*
M?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A
M8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C
M86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q
M.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`]
M(&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H
M85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG
M*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS
M92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN
M;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*
M?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I
M;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I
M.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I
M92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@
M)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H
M97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E
M('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP
M+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM
M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE
M<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M
M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY
M("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%
M35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@
M7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3
M:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T
M<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T
M:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R
M+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L
M("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S
M("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL
M97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@
M6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@
M+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R
M96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A
M<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&
M:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M
M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R
M.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A
M<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0[
M"G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V
M86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ
M571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@
M?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*
M979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R
M('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M
M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF
M;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$
M25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O
M=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@
M)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*
M979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM]
M.PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA
M;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U
M:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@
M/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]
M"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N
M9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM
M>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES
M<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@
M>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B
M=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A
M8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O
M9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@
M;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD
M8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE
M>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%
M3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]
M"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&5X="P@)&-R8RD@/2!`7SL*;7D@*"1F
M:"P@)&9I;&5N86UE*3L*)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X
M="(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*=6YL:6YK("1F:6QE;F%M92!I
M9B`M92`D9FEL96YA;64["G!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*?0IE
M;'-E('L*<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N
M86UE*3L*?0IO<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB
M:6YM;V1E*"1F:"D["G)E='5R;B@D9F@L("1F:6QE;F%M92D["GT*<W5B(%]S
M971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@
M86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE
M(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!]
M(&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2![
M"B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!2
M3T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E
M='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E
M>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]
M"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P
M?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1
M)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA
M;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\
M?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D
M0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z
M.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ
M1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W
M9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]
M7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[
M4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*
M)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$
M(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@
M*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$
M25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%
M3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?
M7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE
M=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%2
M7T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE
M86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@
M)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O
M=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D
M;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@
M:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E
M9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X
M<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C
M:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@
M4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O
M<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L
M('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R
M>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z
M.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I
M92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z
M.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?
M7PH`````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````$````!`````0```=\````!```"+@````P`
M`!<8````#0``4^`````9``'\F````!L````$````&@`!_)P````<````!&__
M_O4```&(````!0``".0````&```"9`````H```3O````"P```!`````5````
M``````,``?\$`````@```O0````4````!P```!<``!0D<``````!_O@````'
M```/1`````@```?4````"0````P````8`````&____L(```!;____@``#J1O
M____`````F____````W4;___^0```%L`````````````````````````````
M```````````````````````````````!_>0`````````````4J```%*D``!2
MJ```4JP``%*P``!2M```4K@``%*\``!2P```4L0``%+(``!2S```4M```%+4
M``!2V```4MP``%+@``!2Y```4N@``%+L``!2\```4O0``%+X``!2_```4P``
M`%,$``!3"```4PP``%,0``!3%```4Q@``%,<``!3(```4R0``%,H``!3+```
M4S```%,T``!3.```4SP``%-```!31```4T@``%-,``!34```4U0``%-8``!3
M7```4V```%-D``!3:```4VP``%-P``!3=```4W@``%-\``!3@```4X0``%.(
M``!3C```4Y```%.4``!3F````````````````````````````````/____\`
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````$=#0SH@*%5B=6YT
M=2`U+C0N,"TV=6)U;G1U,2D@-2XT+C`@,C`Q-C`V,#D``"YS:'-T<G1A8@`N
M:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N
M:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO
M;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O
M9&%T80`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N
M9V]T,@`N9'EN86UI8P`N9V]T`"YD871A`"YS9&%T80`N8G-S`"YC;VUM96YT
M````````````````````````````````````````````````````````````
M``L````!`````@```30```$T````#0```````````````0`````````3````
M!P````(```%$```!1````"````````````````0`````````(0````<````"
M```!9````60````D```````````````$`````````#1O___V`````@```8@`
M``&(````W`````4`````````!`````0````^````"P````(```)D```"9```
M!H`````&`````@````0````0````1@````,````"```(Y```".0```3O````
M```````````!`````````$YO____`````@``#=0```W4````T`````4`````
M`````@````(```!;;____@````(```ZD```.I````*`````&`````@````0`
M````````:@````0````"```/1```#T0```3@````!0`````````$````#```
M`'0````$````0@``%"0``!0D```"]`````4````6````!`````P```!^````
M`0````8``!<8```7&````$0```````````````0`````````A`````$````&
M```78```%V```#R````````````````@`````````(H````!````!@``4^``
M`%/@````+```````````````!`````````"0`````0````(``%0,``!4#```
M030```````````````0`````````F`````$````"``"50```E4`````$````
M```````````$`````````*(````.`````P`!_)@``/R8````!```````````
M````!`````````"N````#P````,``?R<``#\G`````0```````````````0`
M````````N@````$````#``'\H```_*`````$```````````````$````````
M`+\````!`````P`!_*0``/RD```!0````````````````0````````#%````
M!@````,``?WD``#]Y````1`````&``````````0````(````S@````$````#
M``'^]```_O0````0```````````````$````!````'D````!`````P`!_P0`
M`/\$````_```````````````!`````````#3`````0````,``@````$`````
M`&@```````````````0`````````V0````$````#``(`:``!`&@````$````
M```````````$`````````.`````(`````P`"`&P``0!L```0&```````````
M````!`````````#E`````0```#````````$`;````"P```````````````$`
K```!`````0````,````````````!`)@```#N```````````````!````````
